import { apiClient } from "@/lib/api/api-client";
import ApiClientFormData from "@/services/ApiClientFormData";
import useErrorStore from "@/store/useErrorStore";

export const startChatService = async (id_chatbot: string) => {
    try {
        const response = await apiClient.post('chat/startChat',{
            id_chatbot:id_chatbot
        });
        return response.data;
    }catch (error) {
        return { data: null, error: error,status:500};
    } 
}

export const initChatService = async (id_chatbot: string) => {
    try {
        const response = await apiClient.post('chat/initChat',{
            id_chatbot:id_chatbot
        });
        return response.data;
    }catch (error) {
        return { data: null, error: error,status:500};
    } 
}

export const showMessages = async (id_chatbot: string,sesion: string) => {
    try {
        const response = await apiClient.post('chat/showMessages',{
            id_chatbot:id_chatbot,
            sesion:sesion
        });
        return response.data;
    }catch (error:any) {
        if (error.response.status === 401) {
            useErrorStore.getState().incrementError();
        }
        return { data: null, error: error,status:500};
    } 
}

export const getListConversations = async (id_chatbot : string) => {
    try {
        const response = await apiClient.post('chat/getListConversations',{
            id_chatbot:id_chatbot
        });
        return response.data;
    }catch (error :any) {
        if (error.response.status === 401) {
            useErrorStore.getState().incrementError();
        }
        return { data: null, error: error,status:500};
    } 
}

export const createMessage = async (id_chatbot: string, sesion: string, message: string) => {
    try {
        const response = await apiClient.post('chat/createMessage',{
            id_chatbot:id_chatbot,
            sesion:sesion,
            message:message
        });
        return response.data;
    }catch (error) {
        return { data: null, error: error,status:500};
    }
}

export const createMessageFile = async (id_chatbot: string, sesion: string, file: File | undefined) => {
    try {
        const formData = new FormData();
        if (file) {
            formData.append('files', file);
        }
        formData.append('id_chatbot', id_chatbot);
        formData.append('sesion', sesion);
        const response = await ApiClientFormData.post('chat/createMessageFile',formData);
        return response.data;
    }catch (error) {
        return { data: null, error: error,status:500};
    }
}

export const createMessageFileDragAndDrop = async (id_chatbot: string, sesion: string, files: File[]) => {
    try {
        const formData = new FormData();
        // Agregar cada archivo al objeto FormData
        for (let i = 0; i < files.length; i++) {
            formData.append('files[]', files[i]);
        }
        formData.append('id_chatbot', id_chatbot);
        formData.append('sesion', sesion);
        const response = await ApiClientFormData.post('chat/createMessageFileDragAndDrop',formData);
        return response.data;
    }catch (error) {
        return { data: null, error: error,status:500};
    }
}

export const createMessageFileAudio = async (id_chatbot: string, sesion: string, file: File) => {
    try {
        const formData = new FormData();
        formData.append('files', file);
        formData.append('id_chatbot', id_chatbot);
        formData.append('sesion', sesion);
        const response = await ApiClientFormData.post('chat/createMessageFileAudio',formData);
        return response.data;
    }catch (error) {
        return { data: null, error: error,status:500};
    }
}

export const getInfoAgentOnline = async (id_chatbot : string) => {
    try {
        const response = await apiClient.post('chat/getInfoAgentOnline',{
            id_chatbot:id_chatbot
        });
        return response.data;
    }catch (error :any) {
        if (error.response.status === 401) {
            useErrorStore.getState().incrementError();
        }
        return { data: null, error: error,status:500};
    } 
}

export const showMessagesTotalService = async (id_chatbot : string, sesion: string) => {
    try {
        const response = await apiClient.post('chat/showMessagesTotal',{
            id_chatbot:id_chatbot,
            sesion:sesion
        });
        return response.data;
    }catch (error :any) {
        if (error.response.status === 401) {
            useErrorStore.getState().incrementError();
        }
        return { data: null, error: error,status:500};
    } 
}

export const getDetailMessage = async (id_chatbot: string, id_log: string) => {
    try {
        const response = await apiClient.post('chat/getDetailMessage',{
            id_chatbot:id_chatbot,
            id_log:id_log
        });
        return response.data;
    }catch (error) {
        return { data: null, error: error,status:500};
    }
}
